<template>
    <div>
        <v-app class="vue-front-end-fixed">
              <location-confirmation ref="already_fan" 
              width="500"
              :confirm_button_color="'#FFFF00'"
              :cancel_button_color="'grey'"
              :loading="true"
              :msg="''" 
              :show_confirm="true"
              :show_close="true"
              :confirm_button="'Continue'"
              @confirm="saveOrder"
              @close="closeModel"
              >
                <ValidationObserver ref="cart_form">
                    <v-row>
                        <v-col cols="12">
                            <h3>Already a Fan? </h3>
                        </v-col>
                        <v-col cols="12" class="pt-0 pb-0">
                            <ValidationProvider name="First Name" rules="required" >
                                <v-text-field
                                    type="text"
                                    label="First Name*"
                                    v-model="cart_data.first_name"
                                    slot-scope="{errors}"
                                    :error-messages="errors"
                                    outlined
                                    class="white_textbox"
                                ></v-text-field>
                            </ValidationProvider>
                        </v-col>
                        <v-col cols="12" class="pt-0 pb-0">
                            <ValidationProvider name="Last Name" rules="required" >
                                <v-text-field
                                    type="text"
                                    label="Last Name*"
                                    v-model="cart_data.last_name"
                                    slot-scope="{errors}"
                                    :error-messages="errors"
                                    outlined
                                    class="white_textbox"
                                ></v-text-field>
                            </ValidationProvider>
                        </v-col>
                        <v-col cols="12" class="pt-0 pb-0">
                            <ValidationProvider name="Email" rules="required|email" >
                                <v-text-field
                                    type="text"
                                    label="Email Address*"
                                    v-model="cart_data.email"
                                    slot-scope="{errors}"
                                    :error-messages="errors"
                                    outlined
                                    class="white_textbox"
                                ></v-text-field>
                            </ValidationProvider>
                        </v-col>
                        <v-col cols="12" lg="12" class="pt-0 pb-0" v-if="is_mobile">
                            <ValidationProvider name="Mobile" rules="digits:10">
                                <v-text-field
                                    class="auto-complete white_textbox"
                                    type="text"
                                    label="Mobile"
                                    v-model="cart_data.mobile"
                                    slot-scope="{errors}"
                                    :error-messages="errors"
                                    outlined
                                ></v-text-field>
                            </ValidationProvider>
                        </v-col>
                        <v-col cols="12" lg="12" class="pt-0 pb-0" v-else>
                            <ValidationProvider name="Daytime Telephone" rules="digits:10">
                                <v-text-field
                                    class="auto-complete white_textbox"
                                    type="text"
                                    label="Daytime Telephone"
                                    v-model="cart_data.daytime_phone"
                                    slot-scope="{errors}"
                                    :error-messages="errors"
                                    outlined
                                ></v-text-field>
                            </ValidationProvider>
                        </v-col>
                        <v-col cols="12" lg="12" class="pt-0 pb-0">
                            <ValidationProvider name="Preferred Contact Time">
                                <v-select
                                    v-model="cart_data.preferred_contact_time"
                                    class="auto-complete white_textbox"
                                    slot-scope="{errors}"
                                    :error-messages="errors"
                                    :items="cart_data.preferred_contact_options"
                                    label="Preferred Contact Time"
                                    outlined
                                ></v-select>
                            </ValidationProvider>
                        </v-col>
                    </v-row>
                </ValidationObserver>
              </location-confirmation>
        </v-app> 
    </div>
</template>
<script>
import LocationConfirmation from '../LocationConfirmation.vue';
import options from '~/assets/options';
import { ValidationObserver } from 'vee-validate';
import {cloneDeep} from 'lodash';
var moment=require('moment')
export default {
    components : {
        LocationConfirmation,
        ValidationObserver
    },
    props : ['cart_data','location','domain_id','is_mobile'],
    data() {
        return {
            
        }
    },
    mounted() {
    },
    methods:{
        openModel() {
            this.$refs.already_fan.view = true;
            setTimeout(() => {
                this.$refs.cart_form.reset();
            }, 300);
            
        },
        closeModel() {
            this.$refs.already_fan.view = false;
        },
        saveOrder() {
            this.$refs.cart_form.validate().then(success=>{
                let cart = cloneDeep(this.cart_data);
                cart.convert_order = true;
                cart["tag_name"] = "Already a Fan";
                if(cart.dob!=null && cart.dob!='') {
                    cart.dob = moment(cart.dob,'DD/MM/YYYY').format('YYYY-MM-DD');
                }
                if(success) {
                    let cart_data = [];
                    this.cart_data.cart_details.forEach((a,i)=>{
                        let push_data = {
                            item_name       : a.product.name,
                            item_id         : a.product.id,
                            price           : a.product_price,
                            quantity        : a.qty,
                            variant_id      : a.selected_price_type,
                            item_category   : (a.product.default_category!=null) ? a.product.default_category.name : ""
                        };
                        cart_data.push(push_data);
                    });
                    let purchase_data = {
                        currency            : "AUD",
                        revenue             :this.cart_data.total_amount,
                        shipping            : this.cart_data.shipping_charge,
                        tax                 : 0,
                        admin_fee           : this.cart_data.admin_fee,
                        bond_fee            : this.cart_data.refundable_amount,
                        payment_type        :"Offline",
                        id                  :this.cart_data.id,
                        affiliation         :"",
                    }
                    
                    this.$axios.$post('/api/cart/'+this.cart_data.id+'/'+this.location+'/'+this.domain_id,cart)
                    .then(resp=>{
                        productSelectionGa3(cart_data,purchase_data,'already_a_fan');
                        this.$auth.$storage.setUniversal('confirmed_id',cloneDeep(this.cart_data.id));
                        window.location.href="/cart/order-summary";
                    });
                }
                else{
                    $('html, body').animate({
                        scrollTop: $('.vue-checkout-form').offset().top - 300
                    }, 200);
                }
            });
        }
    }
}
</script>